paidiverpy.models.position_params
=================================

.. py:module:: paidiverpy.models.position_params

.. autoapi-nested-parse::

   Position layer parameters models.

   ..
       !! processed by numpydoc !!


Classes
-------

.. autoapisummary::

   paidiverpy.models.position_params.CalculateCornersParams


Module Contents
---------------

.. py:class:: CalculateCornersParams(/, **data: Any)

   Bases: :py:obj:`paidiverpy.utils.base_model.BaseModel`


   
   Parameters for the overlapping resampling calculation.
















   ..
       !! processed by numpydoc !!

